@@ -2,7 +2,6 @@
 """
 @Author  :   g1879
 @Contact :   g1879@qq.com
-@File    :   common.py
 """
 from html import unescape
 from pathlib import Path
@@ -15,7 +14,6 @@ from typing import Union
 from zipfile import ZipFile
 from urllib.parse import urlparse, urljoin, urlunparse
 from requests import get as requests_get
-from requests.exceptions import ConnectionError as requests_connection_err
 
 from .config import DriverOptions
 
